@@ -65,7 +65,7 @@ $factor *= 3 if ($rpi);    # Raspberry PI is sloooooow
 my $BW = 0;
 foreach my $file (@files) {
     next if ($file =~ /^\.+/ || $file =~ /Test|gif/ || -d "$images_path/$file");
-    print_it($F, "Loadeing Images > $file",'00FFFFFF');
+    print_it($F, "Loading Images > $file",'00FFFFFF');
     my $image = $F->load_image(
         {
             'x'            => 1,
@@ -94,6 +94,7 @@ foreach my $file (@files) {
 } ## end foreach my $file (@files)
 $SIG{'QUIT'} = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
 $SIG{'INT'}  = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
+$F->wait_for_console(1);
 $F->cls('OFF');
 $F->splash($VERSION);
 sleep 1;
@@ -163,7 +164,7 @@ monochrome(flipping());
 or_drawing();
 xor_drawing();
 and_drawing();
-alpha_drawing();
+alpha_drawing() unless ($rpi);
 mask_drawing();
 unmask_drawing();
 animated();
@@ -174,8 +175,8 @@ $F->cls('ON');
 exec('reset');
 
 sub color_mapping {
+    
     print_it($F, 'Color Mapping Test -> Red-Green-Blue');
-
     $F->rbox(
         {
             'filled'   => 1,
@@ -194,6 +195,7 @@ sub color_mapping {
         }
     );
     sleep $factor / 2;
+    
     $F->rbox(
         {
             'filled'   => 1,
@@ -212,6 +214,7 @@ sub color_mapping {
         }
     );
     sleep $factor / 2 unless ($rpi);
+    
     my $image = $F->load_image(
         {
             'x'      => 0,
@@ -227,6 +230,7 @@ sub color_mapping {
 } ## end sub color_mapping
 
 sub plotting {
+    
     print_it($F, 'Plotting Test');
 
     my $s = time + $factor;
@@ -240,6 +244,7 @@ sub plotting {
 
 sub lines {
     my $aa = shift;
+    
     if ($aa) {
         print_it($F, 'Antialiased Line Test');
     } else {
@@ -254,6 +259,7 @@ sub lines {
 
 sub angle_lines {
     my $aa = shift;
+    
     if ($aa) {
         print_it($F, 'Antialiased Angle Line Test');
     } else {
@@ -271,6 +277,7 @@ sub angle_lines {
 } ## end sub angle_lines
 
 sub boxes {
+    
     print_it($F, 'Box Test');
 
     my $s = time + $factor;
@@ -281,6 +288,7 @@ sub boxes {
 } ## end sub boxes
 
 sub filled_boxes {
+    
     print_it($F, 'Filled Box Test');
 
     my $s = time + $factor;
@@ -291,6 +299,7 @@ sub filled_boxes {
 } ## end sub filled_boxes
 
 sub vertical_gradient_boxes {
+    
     print_it($F, 'Vertical Gradient Box Test');
     my $s = time + $factor;
     while (time < $s) {
@@ -326,6 +335,7 @@ sub vertical_gradient_boxes {
 } ## end sub vertical_gradient_boxes
 
 sub hatch_filled_boxes {
+    
     print_it($F, 'Hatch Filled Box Test');
     my $s = time + $factor;
     while (time < $s) {
@@ -354,6 +364,7 @@ sub hatch_filled_boxes {
 } ## end sub hatch_filled_boxes
 
 sub horizontal_gradient_boxes {
+    
     print_it($F, 'Horizontal Gradient Box Test');
 
     my $s = time + $factor;
@@ -393,6 +404,7 @@ sub horizontal_gradient_boxes {
 } ## end sub horizontal_gradient_boxes
 
 sub texture_filled_boxes {
+    
     print_it($F, 'Texture Filled Box Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -412,6 +424,7 @@ sub texture_filled_boxes {
 } ## end sub texture_filled_boxes
 
 sub rounded_boxes {
+    
     print_it($F, 'Rounded Box Test');
 
     my $s = time + $factor;
@@ -422,6 +435,7 @@ sub rounded_boxes {
 } ## end sub rounded_boxes
 
 sub filled_rounded_boxes {
+    
     print_it($F, 'Filled Rounded Box Test');
 
     my $s = time + $factor;
@@ -432,6 +446,7 @@ sub filled_rounded_boxes {
 } ## end sub filled_rounded_boxes
 
 sub hatch_filled_rounded_boxes {
+    
     print_it($F, 'Hatch Filled Rounded Box Test');
 
     my $s = time + $factor;
@@ -444,6 +459,7 @@ sub hatch_filled_rounded_boxes {
 } ## end sub hatch_filled_rounded_boxes
 
 sub vertical_gradient_rounded_boxes {
+    
     print_it($F, 'Vertical Gradient Rounded Box Test');
 
     my $s = time + $factor;
@@ -482,6 +498,7 @@ sub vertical_gradient_rounded_boxes {
 } ## end sub vertical_gradient_rounded_boxes
 
 sub horizontal_gradient_rounded_boxes {
+    
     print_it($F, 'Horizontal Gradient Rounded Box Test');
 
     my $s = time + $factor;
@@ -521,6 +538,7 @@ sub horizontal_gradient_rounded_boxes {
 } ## end sub horizontal_gradient_rounded_boxes
 
 sub texture_filled_rounded_boxes {
+    
     print_it($F, 'Texture Filled Rounded Box Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -541,6 +559,7 @@ sub texture_filled_rounded_boxes {
 } ## end sub texture_filled_rounded_boxes
 
 sub circles {
+    
     print_it($F, 'Circle Test');
 
     my $s = time + $factor;
@@ -551,6 +570,7 @@ sub circles {
 } ## end sub circles
 
 sub filled_circles {
+    
     print_it($F, 'Filled Circle Test');
 
     my $s = time + $factor;
@@ -561,6 +581,7 @@ sub filled_circles {
 } ## end sub filled_circles
 
 sub hatch_filled_circles {
+    
     print_it($F, 'Hatch Filled Circle Test');
 
     my $s = time + $factor;
@@ -573,6 +594,7 @@ sub hatch_filled_circles {
 } ## end sub hatch_filled_circles
 
 sub vertical_gradient_circles {
+    
     print_it($F, 'Vertical Gradient Circle Test');
 
     my $s = time + $factor;
@@ -605,6 +627,7 @@ sub vertical_gradient_circles {
 } ## end sub vertical_gradient_circles
 
 sub horizontal_gradient_circles {
+    
     print_it($F, 'Horizontal Gradient Circle Test');
 
     my $s = time + $factor;
@@ -638,6 +661,7 @@ sub horizontal_gradient_circles {
 } ## end sub horizontal_gradient_circles
 
 sub texture_filled_circles {
+    
     print_it($F, 'Texture Filled Circle Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -656,6 +680,7 @@ sub texture_filled_circles {
 } ## end sub texture_filled_circles
 
 sub arcs {
+    
     print_it($F, 'Arc Test');
 
     my $s = time + $factor;
@@ -666,6 +691,7 @@ sub arcs {
 } ## end sub arcs
 
 sub poly_arcs {
+    
     print_it($F, 'Poly Arc Test');
     my $s = time + $factor;
     while (time < $s) {
@@ -675,6 +701,7 @@ sub poly_arcs {
 } ## end sub poly_arcs
 
 sub filled_pies {
+    
     print_it($F, 'Filled Pie Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
@@ -685,6 +712,7 @@ sub filled_pies {
 } ## end sub filled_pies
 
 sub hatch_filled_pies {
+    
     print_it($F, 'Hatch Filled Pie Test');
 
     my $s = time + ($factor * 2);
@@ -697,6 +725,7 @@ sub hatch_filled_pies {
 } ## end sub hatch_filled_pies
 
 sub vertical_gradient_pies {
+    
     print_it($F, 'Vertical Gradient Filled Pie Test');
 
     my $s = time + $factor;
@@ -728,6 +757,7 @@ sub vertical_gradient_pies {
 } ## end sub vertical_gradient_pies
 
 sub horizontal_gradient_pies {
+    
     print_it($F, 'Horizontal Gradient Filled Pie Test');
 
     my $s = time + $factor;
@@ -762,6 +792,7 @@ sub horizontal_gradient_pies {
 } ## end sub horizontal_gradient_pies
 
 sub texture_filled_pies {
+    
     print_it($F, 'Texture Filled Pie Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -785,6 +816,7 @@ sub texture_filled_pies {
 } ## end sub texture_filled_pies
 
 sub ellipses {
+    
     print_it($F, 'Ellipse Test');
 
     my $s = time + $factor;
@@ -795,6 +827,7 @@ sub ellipses {
 } ## end sub ellipses
 
 sub filled_ellipses {
+    
     print_it($F, 'Filled Ellipse Test');
 
     my $s = time + $factor;
@@ -805,6 +838,7 @@ sub filled_ellipses {
 } ## end sub filled_ellipses
 
 sub hatch_filled_ellipses {
+    
     print_it($F, 'Hatch Filled Ellipse Test');
 
     my $s = time + $factor;
@@ -817,6 +851,7 @@ sub hatch_filled_ellipses {
 } ## end sub hatch_filled_ellipses
 
 sub vertical_gradient_ellipses {
+    
     print_it($F, 'Vertical Gradient Ellipse Test');
 
     my $s = time + $factor;
@@ -847,6 +882,7 @@ sub vertical_gradient_ellipses {
 } ## end sub vertical_gradient_ellipses
 
 sub horizontal_gradient_ellipses {
+    
     print_it($F, 'Horizontal Gradient Ellipse Test');
 
     my $s = time + $factor;
@@ -878,6 +914,7 @@ sub horizontal_gradient_ellipses {
 } ## end sub horizontal_gradient_ellipses
 
 sub texture_filled_ellipses {
+    
     print_it($F, 'Image Filled Ellipse Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -897,6 +934,7 @@ sub texture_filled_ellipses {
 } ## end sub texture_filled_ellipses
 
 sub polygons {
+    
     my $aa = shift;
     if ($aa) {
         print_it($F, 'Antialiased Polygon Test');
@@ -912,6 +950,7 @@ sub polygons {
 } ## end sub polygons
 
 sub filled_polygons {
+    
     print_it($F, 'Filled Polygon Test');
 
     my $s = time + $factor;
@@ -932,6 +971,7 @@ sub filled_polygons {
 } ## end sub filled_polygons
 
 sub hatch_filled_polygons {
+    
     print_it($F, 'Hatch Filled Polygon Test');
 
     my $s = time + $factor;
@@ -955,6 +995,7 @@ sub hatch_filled_polygons {
 } ## end sub hatch_filled_polygons
 
 sub vertical_gradient_polygons {
+    
     print_it($F, 'Vertical Gradient Polygon Test');
 
     my $s = time + $factor;
@@ -985,6 +1026,7 @@ sub vertical_gradient_polygons {
 } ## end sub vertical_gradient_polygons
 
 sub horizontal_gradient_polygons {
+    
     print_it($F, 'Horizontal Gradient Polygon Test');
 
     my $s = time + $factor;
@@ -1016,6 +1058,7 @@ sub horizontal_gradient_polygons {
 } ## end sub horizontal_gradient_polygons
 
 sub texture_filled_polygons {
+    
     print_it($F, 'Texture Filled Polygon Test');
 
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
@@ -1037,6 +1080,7 @@ sub texture_filled_polygons {
 } ## end sub texture_filled_polygons
 
 sub beziers {
+    
     print_it($F, 'Testing Bezier Curves');
 
     my $s = time + $factor;
@@ -1051,6 +1095,7 @@ sub beziers {
 } ## end sub beziers
 
 sub truetype_fonts {
+    
     print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
     my @fonts = (keys %{ $F->{'FONTS'} });
@@ -1084,6 +1129,7 @@ sub truetype_fonts {
 } ## end sub truetype_fonts
 
 sub rotate_truetype_fonts {
+    
     print_it($F, 'Testing TrueType Font Rotation Rendering');
 
     my $g     = time + $factor * 3;
@@ -1118,6 +1164,7 @@ sub rotate_truetype_fonts {
 } ## end sub rotate_truetype_fonts
 
 sub flood_fill {
+    
     print_it($F, 'Testing flood fill');
     $F->clip_reset();
     my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
@@ -1150,6 +1197,7 @@ sub flood_fill {
 } ## end sub flood_fill
 
 sub color_replace_with_clipping {
+    
     print_it($F, 'Testing Color Replace (clipping on)');
 
     my $x = $F->{'XRES'} / 4;
@@ -1183,6 +1231,7 @@ sub color_replace_with_clipping {
 } ## end sub color_replace_with_clipping
 
 sub color_replace_no_clipping {
+    
     print_it($F, 'Testing Color Replace (clipping off)');
 
     $F->splash($VERSION);
@@ -1216,6 +1265,7 @@ sub color_replace_no_clipping {
 } ## end sub color_replace_no_clipping
 
 sub blitting {
+    
     print_it($F, 'Testing Image blitting');
 
     my $image = $SMALL_IMAGES[int(rand(scalar(@IMAGES)))];
@@ -1229,11 +1279,13 @@ sub blitting {
 } ## end sub blitting
 
 sub rotate {
+    
     print_it($F, 'Scaling image for Rotate Test', 'FFFF00FF');
 
     my $image = { %{ $SMALL_IMAGES[int(rand(scalar(@IMAGES)))] } };
 
     foreach my $p (0 .. 1) {
+        
         next if ($F->{'BITS'} == 16);
         my $angle = 0;
 
@@ -1309,6 +1361,7 @@ sub rotate {
 
 sub flipping {
     my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
+    
 
     $image->{'y'} = $F->{'Y_CLIP'};
     my $s = time + $factor;
@@ -1333,6 +1386,7 @@ sub flipping {
 
 sub monochrome {
     my $image = $SMALL_IMAGES[int(rand(scalar(@IMAGES)))];
+    
 
     print_it($F, 'Testing Monochrome Image blitting');
 
@@ -1348,6 +1402,7 @@ sub monochrome {
 } ## end sub monochrome
 
 sub animated {
+    
     print_it($F, 'Testing Animated Images.  Loading...', 'FFFF00FF');
     opendir(my $DIR, $images_path);
     chomp(my @list = readdir($DIR));
@@ -1357,6 +1412,7 @@ sub animated {
     foreach my $info (@list) {
         next unless ($info =~ /\.gif$/i);
         for my $count (0 .. 1) {
+            
             if ($count || $XX <= 320) {
                 print_it($F, "Loading Animated Image '$info' Scaled to Full Screen", 'FFFF00FF');
                 $image = $F->load_image(
@@ -1376,6 +1432,7 @@ sub animated {
                     }
                 );
             } ## end else [ if ($count || $XX <= 320)]
+            
 
             foreach my $bench (0 .. 1) {
                 if ($count || $XX <= 320) {
@@ -1388,6 +1445,7 @@ sub animated {
                     my $fps   = 0;
                     my $start = time;
                     my $s     = time + ($factor * 2);
+                    
                     while (time <= $s) {
                         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                             if (time > $s * 2) {
@@ -1419,6 +1477,7 @@ sub animated {
 } ## end sub animated
 
 sub or_drawing {
+    
     print_it($F, 'Testing OR Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
     my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
@@ -1426,18 +1485,22 @@ sub or_drawing {
     $F->or_mode();
     $F->blit_write($image);
     sleep 2;
+    
     $F->blit_write($image2);
     sleep 2;
+    
     my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
     my $mid  = int($XX / 2);
 
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
     $F->circle({ 'x' => $mid - ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
     $F->circle({ 'x' => $mid, 'y' => $F->{'Y_CLIP'} + $size, 'radius' => $size, 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
     $F->circle({ 'x' => $mid + ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
@@ -1445,6 +1508,7 @@ sub or_drawing {
 } ## end sub or_drawing
 
 sub xor_drawing {
+            
     print_it($F, 'Testing XOR Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
     my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
@@ -1452,16 +1516,20 @@ sub xor_drawing {
     $F->xor_mode();
     $F->blit_write($image);
     sleep 2;
+    
     $F->blit_write($image2);
     sleep 2;
+    
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255 });
     $F->rbox({ 'x' => 0, 'y' => 0, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 255 });
     $F->rbox({ 'x' => $XX / 4, 'y' => $YY / 4, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0 });
     $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
@@ -1469,28 +1537,35 @@ sub xor_drawing {
 } ## end sub xor_drawing
 
 sub and_drawing {
+    
     print_it($F, 'Testing AND Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
     my $image2 = $IMAGES[int(rand(scalar(@IMAGES)))];
 
     $F->set_b_color({ 'red' => 255, 'green' => 255, 'blue' => 255 });
+    
     $F->cls();
     $F->and_mode();
     $F->blit_write($image);
     sleep 1;
+    
     $F->blit_write($image2);
     sleep 1;
+    
     my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
     my $mid  = int($XX / 2);
 
     sleep .1;
+    
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
     $F->circle({ 'x' => $mid - ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
     $F->circle({ 'x' => $mid, 'y' => $F->{'Y_CLIP'} + $size, 'radius' => $size, 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
     $F->circle({ 'x' => $mid + ($size / 2), 'y' => $F->{'Y_CLIP'} + $size * 2, 'radius' => $size, 'filled' => 1 });
@@ -1499,6 +1574,7 @@ sub and_drawing {
 } ## end sub and_drawing
 
 sub alpha_drawing {
+    
     $F->attribute_reset();
     print_it($F, 'Testing Alpha Drawing Mode');
     my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
@@ -1508,17 +1584,21 @@ sub alpha_drawing {
     $image2->{'image'} |= pack('C4', 0, 0, 0, 128) x $size;
     $F->blit_write($image);
     sleep 2;
+    
     $F->alpha_mode();
     $F->blit_write($image2);
     sleep 2;
+    
 
     $F->set_color({ 'red' => 0, 'green' => 255, 'blue' => 255, 'alpha' => rand(256) });
     $F->rbox({ 'x' => 0, 'y' => 0, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 255, 'green' => 0, 'blue' => 255, 'alpha' => rand(256) });
     $F->rbox({ 'x' => $XX / 4, 'y' => $YY / 4, 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
     sleep .1;
+    
 
     $F->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0, 'alpha' => rand(256) });
     $F->rbox({ 'x' => ($XX / 2), 'y' => ($YY / 2), 'width' => ($XX / 2), 'height' => ($YY / 2), 'filled' => 1 });
@@ -1526,6 +1606,7 @@ sub alpha_drawing {
 } ## end sub alpha_drawing
 
 sub mask_drawing {
+    
     $F->attribute_reset();
     print_it($F, 'Testing MASK Drawing Mode (This may be SLOW)');
 
@@ -1540,6 +1621,7 @@ sub mask_drawing {
 } ## end sub mask_drawing
 
 sub unmask_drawing {
+    
     print_it($F, 'Testing UNMASK Drawing Mode (This may be SLOW)');
 
     my $h      = int($YY - $F->{'Y_CLIP'});
